@@ -381,12 +381,12 @@ WITH entity_dataframe AS (
             {% if featureview.entities %}
             ,(
                 {% for entity in featureview.entities %}
-                    CAST("{{entity}}" as CHAR) ||
+                    CAST({{entity}} as CHAR) ||
                 {% endfor %}
-                CAST("{{entity_df_event_timestamp_col}}" AS CHAR)
+                CAST({{entity_df_event_timestamp_col}} AS CHAR)
             ) AS "{{featureview.name}}__entity_row_unique_id"
             {% else %}
-            ,CAST("{{entity_df_event_timestamp_col}}" AS CHAR) AS "{{featureview.name}}__entity_row_unique_id"
+            ,CAST({{entity_df_event_timestamp_col}} AS CHAR) AS "{{featureview.name}}__entity_row_unique_id"
             {% endif %}
         {% endfor %}
     FROM {{ left_table_query_string }}
